@@ -7,13 +7,6 @@ completely.
 from distutils.core import setup
 
 something = dict()
-something['fish'] = ['a', 'b', 'c']
+something["fish"] = ["a", "b", "c"]
 
-setup(
-    name='prospector-test-1',
-    version='0.0.1',
-    install_requires=(
-        'Django==1.5.0',
-        'django-gubbins==1.1.2'
-    )
-)
\ No newline at end of file
+setup(name="prospector-test-1", version="0.0.1", install_requires=("Django==1.5.0", "django-gubbins==1.1.2"))
